@@ -192,23 +192,23 @@ if __name__ == '__main__':
 	
 	mainWindow = Ui_MainWindow()
 	mainWindow.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow)
-	mainWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
+	#mainWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
 	
 	inboxWindow = Ui_InboxWindow(mainWindow)
 	inboxWindow.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow)
-	inboxWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
+	#inboxWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
 	
 	sentWindow = Ui_SentWindow(mainWindow)
 	sentWindow.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow)
-	sentWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
+	#sentWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
 	
 	inboxMsgWindow = Ui_MessageWindow(inboxWindow)
 	inboxMsgWindow.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow)
-	inboxMsgWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
+	#inboxMsgWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
 	
 	sentMsgWindow = Ui_MessageWindow(sentWindow)
 	sentMsgWindow.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow)
-	sentMsgWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
+	#sentMsgWindow.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
 	
 	
 	
